package com.me.pacman;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;

public class FontRenderer {


    public static final char[] CHARS = "abcdefghijklmnopqrstuvwxyz0123456789!?()[]<>$&*:#^~-_/\\".toCharArray();
    public static final int[] CHAR_TO_INDEX = new int[256];
    private Color color = Color.WHITE;

    private TextureRegion[][] sprites;

    public FontRenderer(TextureRegion[][] sprites) {
        this.sprites = sprites;
    }

    public void setColor(Color color) {
        this.color = color;
    }

    public void draw(SpriteBatch batch, String str, int x, int y) {
        float oldColor = batch.getPackedColor();
        batch.setColor(color);

        for (char c : str.toCharArray()) {
            if (Character.isWhitespace(c)) {
                x += 8;
                continue;
            }
            int i = CHAR_TO_INDEX[c];
            TextureRegion region = sprites[i / 8][i % 8];
            batch.draw(region, x, y);
            x += 8;
        }

        batch.setPackedColor(oldColor);
    }

    static {
        for (int i = 0; i < CHARS.length; i++) {
            CHAR_TO_INDEX[CHARS[i]] = i;
        }
    }

}
