package com.me.pacman;

import com.badlogic.gdx.Game;
import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.utils.viewport.FitViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.me.pacman.state.HighScoresState;
import com.me.pacman.state.MenuState;
import com.me.pacman.state.State;

public class PacDude extends Game {

	public static final String TITLE = "Pac-Dude";
	public static final String VERSION = "v0.1.0";

	public static final boolean DEBUG = false;

	public static final int LEVEL_WIDTH = 224;
	public static final int LEVEL_HEIGHT = 288;

	public HighScores highScores;

	public Assets assets;
	public Sound sound;

	public SpriteBatch batch;
	public FontRenderer fontRenderer;

	public OrthographicCamera cam;
	public Viewport viewport;

	private State nextState;

	@Override
	public void create () {
		cam = new OrthographicCamera();
		viewport = new FitViewport(LEVEL_WIDTH, LEVEL_HEIGHT, cam);
		viewport.apply(true);

		highScores = new HighScores();

		assets = new Assets();
		assets.loadAssets();
		sound = new Sound(this);

		batch = new SpriteBatch();
		fontRenderer = new FontRenderer(assets.font);

		Gdx.gl.glClearColor(0, 0, 0, 1);
		setNextState(new MenuState(this));
	}

	@Override
	public void render () {
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

		if (nextState != null) {
			Screen currScreen = getScreen();
			if (currScreen != null) currScreen.dispose();
			nextState.setup();
			super.setScreen(nextState);
			nextState = null;
		}

		batch.begin();
		if (DEBUG) {
			fontRenderer.draw(batch, "fps:" + Gdx.graphics.getFramesPerSecond(), 19 * 8, 34 * 8);
		}
		super.render();
		batch.end();
	}

	@Override
	public void resize(int width, int height) {
		viewport.update(width, height);

		batch.setProjectionMatrix(cam.combined);

		super.resize(width, height);
	}

	@Override
	public void dispose () {
		batch.dispose();
		assets.dispose();
	}

	@Override
	public void setScreen(Screen screen) {
		throw new IllegalStateException("Use setNextState instead.");
	}

	public void setNextState(State state) {
		this.nextState = state;
	}

}
